@@ -148,7 +148,6 @@ typedef struct __xconfigoptionrec {
     struct __xconfigoptionrec *next;
     char *name;
     char *val;
-    int   used;
     char *comment;
 } XConfigOptionRec, *XConfigOptionPtr;
 
@@ -592,10 +591,6 @@ typedef struct {
     char *keyboard;
     char *mouse;
     char *keyboard_driver;
-
-    int supports_extension_section;
-    int autoloads_glx;
-
 } GenerateOptions;
 
 
@@ -656,6 +651,8 @@ void xconfigFreeVideoPortList(XConfigVideoPortPtr ptr);
 void xconfigFreeBuffersList (XConfigBuffersPtr ptr);
 void xconfigFreeDRI(XConfigDRIPtr ptr);
 void xconfigFreeExtensions(XConfigExtensionsPtr ptr);
+void xconfigFreeModesLinkList(XConfigModesLinkPtr ptr);
+
 
 
 /*
@@ -677,22 +674,20 @@ XConfigLoadPtr xconfigRemoveLoadDirective(XConfigLoadPtr head,
  */
 
 XConfigOptionPtr xconfigAddNewOption(XConfigOptionPtr head,
-                                     char *name, char *val);
+                                     const char *name, const char *val);
 XConfigOptionPtr xconfigRemoveOption(XConfigOptionPtr list,
                                      XConfigOptionPtr opt);
 XConfigOptionPtr xconfigOptionListDup(XConfigOptionPtr opt);
 void             xconfigOptionListFree(XConfigOptionPtr opt);
 char            *xconfigOptionName(XConfigOptionPtr opt);
 char            *xconfigOptionValue(XConfigOptionPtr opt);
-XConfigOptionPtr xconfigNewOption(char *name, char *value);
+XConfigOptionPtr xconfigNewOption(const char *name, const char *value);
 XConfigOptionPtr xconfigNextOption(XConfigOptionPtr list);
 XConfigOptionPtr xconfigFindOption(XConfigOptionPtr list, const char *name);
 char            *xconfigFindOptionValue(XConfigOptionPtr list,
                                         const char *name);
 int              xconfigFindOptionBoolean (XConfigOptionPtr,
                                            const char *name);
-XConfigOptionPtr xconfigOptionListCreate(const char **options,
-                                         int count, int used);
 XConfigOptionPtr xconfigOptionListMerge(XConfigOptionPtr head,
                                         XConfigOptionPtr tail);
 
@@ -729,10 +724,6 @@ void xconfigGenerateAssignScreenAdjacencies(XConfigLayoutPtr layout);
 
 void xconfigGeneratePrintPossibleMice(void);
 void xconfigGeneratePrintPossibleKeyboards(void);
-void xconfigGenerateLoadDefaultOptions(GenerateOptions *gop);
-
-void xconfigGetXServerInUse(GenerateOptions *gop);
-
 
 /*
  * check (and update, if necessary) the inputs in the specified layout
@@ -742,4 +733,13 @@ void xconfigGetXServerInUse(GenerateOptions *gop);
 int xconfigCheckCoreInputDevices(GenerateOptions *gop,
                                  XConfigPtr config, XConfigLayoutPtr layout);
 
+
+/*
+ * X config tools
+ */
+
+int xconfigMergeConfigs(XConfigPtr dstConfig, XConfigPtr srcConfig);
+
+
+
 #endif /* _xf86Parser_h_ */
